@@ -1481,6 +1481,7 @@ int myputc(c) {
 int write_player_track(track) {
 	register unsigned int iteration;
 	
+	playerCount = track;
 	memset(melop, 0, MAX_RECURSION*2);
 	if(!globalWritten) {
 		if(!mf_write_meta_event(0, copyright_notice, copyright, strlen(copyright))) {
@@ -1490,6 +1491,9 @@ int write_player_track(track) {
 		mf_write_tempo((long)60000000/tempo);
 		globalWritten++;
 	}
+	prev_duration=0;
+	if(!debugOption)
+		printf("Player %s is generating...\n", players[playerCount]->identifier);
 	players[playerCount]->num?(data[0]=players[playerCount]->num):(data[0]=glob_num);
 	players[playerCount]->den?(data[1]=log10(players[playerCount]->den)/log10(2)):(data[1]=log10(glob_den)/log10(2));
 	data[2]=24;
@@ -1526,10 +1530,14 @@ int write_player_track(track) {
 					lindenmayer_generator(hash("axiom", 0), iteration);
 			}
 	}
+	if(!debugOption)
+		printf("\n...ok\n");
 	return 1;
 }
 
 int grammyvm() {
+	unsigned int ntracks;
+
 	if(!strcmp(namefile, ""))
 		strcpy(namefile, DEFAULT_FILENAME);
 	if(!(midi=fopen(namefile, "w"))) {
@@ -1542,16 +1550,7 @@ int grammyvm() {
 	}
 	Mf_putc=myputc;
 	Mf_writetrack=write_player_track;
-	for(playerCount=0; playerCount<NUM_PLAYERS; playerCount++) {
-		if(players[playerCount]) {
-			prev_duration=0;
-			if(!debugOption)
-				printf("Player %s is generating...\n", players[playerCount]->identifier);
-			mfwrite(0, 1, global_resolution, midi);
-			if(!debugOption)
-				printf("\n...ok\n");
-		}
-	}
+	mfwrite(0, playerCount, global_resolution, midi);
 	if(!debugOption)
 		printf("midi file succesfully generated!\n");
 }
